Module foreign_fetcher
ic_
dbms_
api
0.6.0
Module foreign_
fetcher
Module Items
Structs
Traits
In ic_
dbms_
api::
dbms
ic_dbms_api
::
dbms
Module
foreign_
fetcher
Structs

NoForeign
Fetcher
A no-op foreign fetcher that does not perform any fetching.
Traits

Foreign
Fetcher
Fetches related records from foreign tables referenced by foreign keys.