InsertRecord

Trait InsertRecord 

pub trait InsertRecord: Sized + Clone {
    type Record: TableRecord;
    type Schema: TableSchema<Record = Self::Record>;

    // Required methods
    fn from_values(values: &[(ColumnDef, Value)]) -> Result<Self, DbmsError>;
    fn into_values(self) -> Vec<(ColumnDef, Value)>;
    fn into_record(self) -> Self::Schema;
}
This trait represents a record for inserting into a table.

Required Associated Types

type Record: TableRecord

The TableRecord type associated with this table schema.

type Schema: TableSchema<Record = Self::Record>

The table schema associated with this record.

Required Methods

fn from_values(values: &[(ColumnDef, Value)]) -> Result<Self, DbmsError>

Creates an insert record from a list of column Values.

fn into_values(self) -> Vec<(ColumnDef, Value)>

Converts the record into a list of column Values for insertion.

fn into_record(self) -> Self::Schema

Converts the insert record into the corresponding table record.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors