pub trait TableRecord: Clone {
type Schema: TableSchema<Record = Self>;
// Required methods
fn from_values(values: Vec<(ValuesSource, Vec<(ColumnDef, Value)>)>) -> Self;
fn to_values(&self) -> Vec<(ColumnDef, Value)>;
}Expand description
This trait represents a record returned by a crate::dbms::query::Query for a table.
Required Associated Types
Sourcetype Schema: TableSchema<Record = Self>
type Schema: TableSchema<Record = Self>
The table schema associated with this record.
Required Methods
Sourcefn from_values(values: Vec<(ValuesSource, Vec<(ColumnDef, Value)>)>) -> Self
fn from_values(values: Vec<(ValuesSource, Vec<(ColumnDef, Value)>)>) -> Self
Constructs TableRecord from a list of column values grouped by table.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".