UpdateRecord

Trait UpdateRecord 

pub trait UpdateRecord: Sized + Clone {
    type Record: TableRecord;
    type Schema: TableSchema<Record = Self::Record>;

    // Required methods
    fn from_values(
        values: &[(ColumnDef, Value)],
        where_clause: Option<Filter>,
    ) -> Self;
    fn update_values(&self) -> Vec<(ColumnDef, Value)>;
    fn where_clause(&self) -> Option<Filter>;
}
This trait represents a record for updating a table.

Required Associated Types

type Record: TableRecord

The TableRecord type associated with this table schema.

type Schema: TableSchema<Record = Self::Record>

The table schema associated with this record.

Required Methods

fn from_values( values: &[(ColumnDef, Value)], where_clause: Option<Filter>, ) -> Self

Creates an update record from a list of column Values and an optional Filter for the where clause.

fn update_values(&self) -> Vec<(ColumnDef, Value)>

Get the list of column Values to be updated.

fn where_clause(&self) -> Option<Filter>

Get the Filter condition for the update operation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors